import org.faceless.pdf2.*;
import java.io.*;

// This demo is a mockup of a fairly typical case - a template is loaded
// and multiple copies are created with different data. Typically this
// would be run from a Servlet or similar.
//
public class BatchFormFill
{
    // A simple "Person" object, which we will use to populate the
    // template
    //
    private static class Person
    {
        public final String name, country, phone;

	public Person(String name, String country, String phone)
	{
	    this.name=name;
	    this.country=country;
	    this.phone=phone;
	}
    }

    // The main program creates some people as test data, loads the
    // template and the loops round each person, creating a form
    // for them.
    // 
    public static void main(String[] args) throws IOException
    {
	Person[] people = {	new Person("John Bull", "UK", "442078868199"), 
				new Person("Ben Franklin", "US", "12125551234"), 
				new Person("Werner Graf", "DE", "49691234567"), 
				new Person("Jean Reno", "FR", "3325123916"), 
				new Person("Dmitri Papadolou", "GR", "3017891234")
			    };

	FileInputStream in = new FileInputStream("resources/fw8eci.pdf");
        PDF template = new PDF(new PDFReader(in));
	in.close();

	for (int i=0;i<people.length;i++) {
	    createPDF(i, people[i], template);
	}
    }

    // Create a form for the person from the supplied template,
    // and write it to a file called "BatchForm-i.pdf", where "i"
    // is the persons record number.
    //
    static final void createPDF(int i, Person person, PDF template) throws IOException
    {
	// First we clone the PDF, so we're not writing to the
	// original template. In this fairly simple example this is
	// not really necessary, as all we're doing it filling out
	// form fields. More complex example might add bookmarks,
	// add or remove pages and so on, in which case leaving an
	// unaltered original is a good idea.
	//

	PDF pdf = new PDF(template);
	Form form = pdf.getForm();
	((FormText)form.getElement("f1-1")).setValue(person.name);
	((FormText)form.getElement("f1-2")).setValue(person.country);
	((FormText)form.getElement("f1-3")).setValue(person.phone);

	// Flattening the form shaves about 28k off the document size
	// in this case, although it does mean the values are permanently
	// part of the PDF.
	//
	form.flatten();

	System.out.println("Writing \"BatchForm-"+i+".pdf\"");
	FileOutputStream out = new FileOutputStream("BatchForm-"+i+".pdf");
	pdf.render(out);
	out.close();
    }
}
