// $Id: HelloUnicodeWorld.java,v 1.2 2003/11/03 10:56:14 mike Exp $

import java.util.*;
import java.io.*;
import java.awt.Color;
import org.faceless.pdf2.*;

// A more international Hello World example. Unicode text is
// no more difficult than standard Latin text!
//
// A more complete example of internationalization is in
// the "Unicode.java" example
//
public class HelloUnicodeWorld
{
    public static void main(String[] args)
        throws IOException
    {
	if (args.length==0) {
	    System.err.println("Usage: java HelloUnicodeWorld <truetype-font-file>\n\nThis program needs a TrueType font containing Arabic and Cyrllic\ncharacters, like \"times.ttf\" (the Times-Roman supplied with\nMicrosoft Windows 2000.\n\n");
	    System.exit(1);
	}

	// Create a new PDF
	PDF pdf = new PDF();

	// Create a new page
	//
	PDFPage page = pdf.newPage(PDF.PAGESIZE_A4);

	// Create a new "style" to write in - Black 24pt, with whatever font
	// was given on the command line.
	//
	PDFStyle mystyle = new PDFStyle();

	OpenTypeFont otf = new OpenTypeFont(new FileInputStream(args[0]),2);
	mystyle.setFont(otf, 24);
	mystyle.setFillColor(Color.black);

	// Write Hello World in:
	//
	// * English
	// * Russian
	// * Arabic
	// * Czech
	//
	// Diclaimer: We don't actually speak any of these except English
	// (and some would argue that isn't too hot either). Speling
	// mistakes are ours, and ours alone. Thanks to those that emailed
	// additional languages.
	//
	// Feel free to mail corrections, or different languages (greek, thai
	// or hebrew anyone?) to info@big.faceless.org
	//
	// Notice that the arabic letters are all the "nominal" forms, from
	// the U+0600 table. From version 1.0.1 and above, these will be
	// automatically substituted with the appropriate ligature.
	//
	// We're trying to demonstrate is that you can mix and match
	// any unicode character in the same *String*, let alone the same
	// document - which is why this is all on one line and hard to read.
	//
	//
	page.setStyle(mystyle);
	page.drawText("Hello, World\n\u0417\u0434\u0430\u0432\u0441\u0442\u0432\u0443\u0439\u0442\u0435 \u043C\u0438\u0440\n\u010Cau sv\u011bte\n\u0633\u0644\u0627\u0645 \u0627\u0644\u0639\u0627\u0644\u0645\n", 100, page.getHeight()-100);

	// Add some document info
	//
	pdf.setInfo("Author", "Big Faceless Organization");
	pdf.setInfo("Title", "Unicode Text Demonstration");

	// Write the document to a file
	//
	OutputStream fo = new FileOutputStream("HelloUnicodeWorld.pdf");
	pdf.render(fo);
	fo.close();
    }
}
