// $Id: ImageToPDF.java,v 1.3 2004/05/16 21:54:30 mike Exp $

import java.util.*;
import java.io.*;
import org.faceless.pdf2.*;

/**
 * Takes a list of image files on the command line
 * and creates a PDF with each image, one per page.
 * If an image has multiple pages (like some TIFFs),
 * include each one.
 *
 * Recognized file formats include most PNG, GIF, JPEG
 * and TIFF images. Unrecognized files will display an
 * error and the process will continue.
 */
public class ImageToPDF
{
    public static void main(String[] args)
        throws IOException
    {
	if (args.length==0) {
	    System.out.println("Usage: java ImageToPDF <file1> [<file2> ... ]\n");
	    System.out.println("       Creates the file \"ImageToPDF.pdf\"\n\n");
	    System.exit(0);
	}

	PDF pdf = new PDF();

	for (int i=0;i<args.length;i++) {
	    // Load the specified image as a PDFImageSet - even if it only
	    // contains one page, this keeps things simple.
	    //
	    InputStream in = new FileInputStream(args[i]);
	    PDFImageSet imgs = new PDFImageSet(in);
	    in.close();
	    for (int j=0;j<imgs.getNumImages();j++)
	    {
		// For each page in the image set, create a new page in the
		// PDF that's the same size,and display the image.
		//
		PDFImage img = imgs.getImage(j);
		PDFPage page = pdf.newPage((int)img.getWidth(), (int)img.getHeight());
		page.drawImage(img,0,0,page.getWidth(),page.getHeight());
	    }
	}

	OutputStream fo = new FileOutputStream("ImageToPDF.pdf");
	pdf.render(fo);
	fo.close();
    }
}
