import org.faceless.pdf2.*;
import java.io.*;
import java.util.*;

// An example which "stitches" pages together - displaying two pages
// from the original documents on a single page in "2-up" format.
//
// Takes a list of filenames on the command line.
//
// $Id: PageStitch.java,v 1.2 2003/11/03 10:56:14 mike Exp $
//
public class PageStitch
{
    public static void main(String[] args)
        throws IOException
    {
	if (args.length==0) {
	    System.err.println("Usage: java PageStitch <file1.pdf> [<file2.pdf> ...]");
	    System.err.println("       Creates the file \"PageStitch.pdf\"\n");
	    System.exit(0);
	}

	PDF dest = new PDF();
	PDFPage destpage=null;
	List holdlist = new ArrayList();

	// For each filename, add all the pages to the list "holdlist"
	//
	for (int i=0;i<args.length;i++) {
	    PDFReader rd = new PDFReader(new File(args[i]));
	    PDF src = new PDF(rd);
	    holdlist.addAll(src.getPages());
	}


	// Now add the pages from "holdlist" to the new PDF document
	//
	// Note that this takes no account of aspect ratio of the pages.
	// For ISO page sizes this is OK - because the ratio of width
	// to height is sqrt(2), no distortion is introduced. American
	// and Canadian documents with their archaic paper formats may
	// have some distortion introduced.
	//
	for (int i=0;i<holdlist.size();i++)
	{
	    PDFPage srcpage = (PDFPage)holdlist.get(i);

            // In order for the source page to be drawn to a target page it must be made into
            // a Canvas first.

            PDFCanvas canvas = new PDFCanvas(srcpage);

	    // This next block of code takes care of merging two pages into a
	    // single page, by taking the contents of one page and pasting it
	    // onto another.
	    //
	    if (i%2==0)
	    {
		// If it's an even number, make a new page and measure
		// it in percentage points from the top-left.
		//
	        destpage = dest.newPage(PDF.PAGESIZE_A4_LANDSCAPE);
		destpage.setUnits(PDFPage.UNITS_PERCENT, PDFPage.ORIGIN_PAGETOP);

		// Place the contents of the input page on the output page
		// in the rectangle from (0%,0%) to (50%,100%) of the page.
		// Create a canvas of the source page first...
		destpage.drawCanvas(canvas, 0, 0, 50, 100);
	    } else {
		//
		// Place the contents of the input page on the output page
		// in the rectangle from (50%,0%) to (100%,100%) of the page.
		//
		destpage.drawCanvas(canvas, 50, 0, 100, 100);
	    }
	}
        dest.render(new FileOutputStream("PageStitch.pdf"));
    }
}
