// $Id: FDF.java,v 1.4 2003/11/04 17:16:01 mike Exp $

package org.faceless.pdf;

import java.io.*;
import java.util.*;

/**
 * <p>
 * A class representing an <code>FDF</code> object. "FDF" stands for "Forms Data Format",
 * and is Adobes format for submitting form data from a PDF to a server, and generating
 * a response.
 * </p><p>
 * Currently support in the PDF library is limited to completing a PDF documents Form 
 * with the data in the FDF file, using the {@link PDF#importFDF} method.
 * </p><p>
 * Here's a simple example showing how to complete a PDF form with an FDF and save the
 * completed PDF to an <code>OutputStream</code>.
 * </p><pre>
 *   PDF pdf = new PDF(new PDFReader(new FileInputStream("blankform.pdf")));
 *   FDF fdf = new FDF(new InputStream("data.fdf"));
 *   pdf.importFDF(fdf);
 *   pdf.render(outputstream);
 * </pre>
 *
 * @see PDF#importFDF
 * @see Form
 * @since 1.2.1
 * @version $Revision: 1.4 $
 *
 */
public class FDF extends PeeredObject
{
    final org.faceless.pdf2.FDF fdf;

    public FDF(InputStream fdfstream)
        throws IOException
    {
	fdf = new org.faceless.pdf2.FDF(fdfstream);
    }

    Object getPeer()
    {
        return fdf;
    }
}
